@@ -5,7 +5,7 @@ use warnings;
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006';
+our $VERSION   = '0.007';
 
 use Exporter::Shiny qw( theory );
 use List::Util 1.54 ();
@@ -166,6 +166,7 @@ sub fake_animal {
 		'werewolf',
 		'dragon',
 		'wyvern',
+		'yeti',
 	);
 	
 	_MERGE_( $orig_meta, fake_animal => $animal );
@@ -318,6 +319,12 @@ sub artifact {
 		'Excalibur',
 		'the ark of the covenant',
 		"Jesus's foreskin",
+		'the Holy Prepuce',
+		'the Book of the Dead',
+		'the Necronomicon',
+		"the Philosopher's Stone",
+		"a fragment of the true cross",
+		"the seal of Soloman",
 	);
 	
 	_MERGE_( $orig_meta, artifact => $artifact );
@@ -393,6 +400,7 @@ sub myth_place {
 		"Lucifer's crypt",
 		"Jesus's grave",
 		"Jesus's true birthplace",
+		'the entrance to the hollow Earth',
 	);
 	
 	_MERGE_( $orig_meta, myth_place => $place );
@@ -669,6 +677,25 @@ sub biologist {  # and medics
 	return $x;
 }
 
+sub clone {
+	my $orig_meta = shift // {};
+
+	my $x = _RANDOM_(
+		'an alien',
+		'an avatar',
+		'a CGI replica',
+		'a clone',
+		'a cyborg',
+		'a hologram',
+		'a look-alike',
+		'a robot',
+	);
+
+	_MERGE_( $orig_meta, clone => $x );
+	return $x;
+}
+
+
 sub evidence {
 	my $orig_meta = shift // {};
 	
@@ -677,6 +704,8 @@ sub evidence {
 		"there was something about it on Facebook",
 		"the voices told me",
 		"I had a dream",
+		'Pinterest is censoring me',
+		'Reddit was down this morning',
 	);
 
 	if ( my $m = $orig_meta->{misinformation} ) {
@@ -734,8 +763,10 @@ sub evidence {
 		push @x, (
 			"$v died too young",
 			"$v sent a letter containing the truth before dying",
-			"when they did an autopsy on $v it turned out it was a robot",
-			"when they did an autopsy on $v it turned out it was an alien",
+			sub {
+				my $clone = clone( $orig_meta );
+				"when they did an autopsy on $v it turned out it was $clone",
+			},
 			"they never did an autopsy on $v",
 			"$v wrote a will",
 			sub {
@@ -789,7 +820,7 @@ sub evidence {
 		
 		if ( my $p = $orig_meta->{random_place} ) {
 			push @x, (
-				$f->{author} . " has a secret home in $p",
+				$f->{author} . " had a secret home in $p",
 				$f->{author} . " was secretly born in $p",
 			);
 		}
@@ -841,6 +872,7 @@ sub evidence {
 		push @x, (
 			"$f don't taste like they used to",
 			"$f smell funny",
+			"$f make me feel sick",
 			"I don't like $f",
 		);
 	}
@@ -849,15 +881,20 @@ sub evidence {
 		push @x, (
 			"$chem isn't on the periodic table",
 			"$chem isn't real",
+			"$chem isn't natural",
 			"you'd have to be stupid to think $chem is real",
 		);
 	}
 
 	if ( my $r = $orig_meta->{precious_resource} ) {
-		my $bad = $orig_meta->{antagonist}{name}
-			// $orig_meta->{protagonist}{name}
-			// $orig_meta->{shady_group}{name}
-			// shady_group( $orig_meta );
+		my ( $bad, $are );
+		$orig_meta->{shady_group}{name} or shady_group( $orig_meta );
+		foreach ( qw/ antagonist protagonist shady_group / ) {
+			if ( $orig_meta->{$_}{name} ) {
+				$bad = $orig_meta->{$_}{name};
+				$are = $orig_meta->{$_}{plural} ? 'are' : 'is';
+			}
+		}
 		push @x, (
 			"the Wikipedia entry for $r keeps getting edited by $bad",
 			"$bad keeps buying $r secretly on the stock market",
@@ -865,7 +902,7 @@ sub evidence {
 			"have you ever seen $r for real with your own eyes",
 			"$r is so damn expensive",
 			"$r is really rare",
-			"Alex Jones says $bad is linked to $r",
+			"Alex Jones says $bad $are linked to $r",
 		);
 	}
 
@@ -878,6 +915,8 @@ sub evidence {
 			"Bible numerology has clues about $topicname",
 			"$topicname $have always been suspicious",
 			"$topicname $have connections to THEM",
+			"nobody really understands $topicname",
+			"all my posts about $topicname keep getting taken down by Tumblr",
 		);
 	}
 
@@ -1122,11 +1161,6 @@ sub hidden_truth {
 			my $objects = objects( $orig_meta );
 			"$objects are sentient";
 		},
-		sub {
-			my $things = _RANDOM_( 'electrons', 'protons' );
-			$orig_meta->{topic} = { name => $things, plural => 1 };
-			"$things are not real particles, they are just the terminal lines of a dieletric pulse";
-		},
 		sub {
 			my $celebrity = celebrity( $orig_meta );
 			my $long_time = a_long_time( $orig_meta );
@@ -1543,12 +1577,17 @@ sub theory {
 			my $fact = _RANDOM_(
 				sub {
 					$orig_meta->{topic} = { name => 'bathroom scales', plural => 1 };
-					'electrons have mass';
+					'electrons have more mass than protons';
 				},
 				sub {
 					$orig_meta->{topic} = { name => 'weighing scales', plural => 1 };
 					"protons don't have mass";
 				},
+				sub {
+					my $things = _RANDOM_( 'electrons', 'protons' );
+					$orig_meta->{topic} = { name => $things, plural => 1 };
+					"$things are not real particles, they are just the terminal lines of a dieletric pulse";
+				},
 				sub {
 					$orig_meta->{topic} = { name => 'water', plural => 0 };
 					'water is its own element';
@@ -1656,6 +1695,10 @@ sub theory {
 					$orig_meta->{topic} = { name => 'anger managemment', plural => 0 };
 					"wasps are just angry bees";
 				},
+				sub {
+					$orig_meta->{topic} = { name => 'oncology', plural => 0 };
+					"windmills cause cancer";
+				},
 				sub {
 					my $animal = real_animal( $orig_meta );
 					$orig_meta->{topic} = { name => 'space flight', plural => 0 };
@@ -1720,7 +1763,10 @@ sub theory {
 				"$pronoun will probably have to be eliminated",
 				"$pronoun is going to be killed if $pronoun isn't dead already",
 				"$pronoun is being paid to stay quiet",
-				"$pronoun has been replaced by a clone",
+				sub {
+					my $clone = clone( $orig_meta );
+					"$pronoun has been replaced by $clone";
+				},
 				sub {
 					my $place = bad_place( $orig_meta );
 					"$pronoun has been imprisoned in $place";
@@ -1801,7 +1847,7 @@ This module exports one function, C<< theory() >> which returns a string.
 =head1 BUGS
 
 Please report any bugs to
-L<http://rt.cpan.org/Dist/Display.html?Queue=Acme-ConspiracyTheory-Random>.
+L<https://github.com/tobyink/p5-acme-conspiracytheory-random/issues>.
 
 =head1 SEE ALSO
 
